==> owncloud-9.0.3.tgz: owncloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei sind geändert worden",
    "%1$s assigned system tag %3$s" : "%1$s hat System-Tag %3$s angebracht",
    "%1$s unassigned system tag %3$s" : "%1$s hat den System-Tag %3$s entfernt",
    "%1$s created system tag %2$s" : "%1$s hat erstellt System-Tag %2$s",
    "%1$s deleted system tag %2$s" : "%1$s hat System-Tag %2$s gelöscht",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s hat System-Tag %3$s an %2$s angebracht",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s hat den System-Tag %3$s von %2$s entfernt",
    "%s (not-assignable)" : "%s (nicht anbringbar)",
    "%s (invisible)" : "%s (unsichtbar)",
    "Tags" : "Tags",
    "Tagged files" : "Tags",
    "Select tags to filter by" : "Wählen Sie Tags die gefiltert werden sollen",
    "Please select tags to filter by" : "Bitte wählen Sie Tags die gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei sind geändert worden"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tgz: owncloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Tagged files" : "Tags",
    "Select tags to filter by" : "Wählen Sie Tags die gefiltert werden sollen",
    "Please select tags to filter by" : "Bitte wählen Sie Tags die gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei sind geändert worden",
    "You assigned system tag %3$s" : "Sie haben den System-Tag %3$s angebracht",
    "%1$s assigned system tag %3$s" : "%1$s hat System-Tag %3$s angebracht",
    "You unassigned system tag %3$s" : "Sie haben den System-Tag %3$s entfernt",
    "%1$s unassigned system tag %3$s" : "%1$s hat den System-Tag %3$s entfernt",
    "You created system tag %2$s" : "Sie haben den System-Tag %2$s erstellt",
    "%1$s created system tag %2$s" : "%1$s hat erstellt System-Tag %2$s",
    "You deleted system tag %2$s" : "Sie haben den System-Tag %2$s gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat System-Tag %2$s gelöscht",
    "You updated system tag %3$s to %2$s" : "Sie haben den System-Tag %3$s zu %2$s aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "You assigned system tag %3$s to %2$s" : "Sie haben den System-Tag %3$s an %2$s angebracht",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s hat System-Tag %3$s an %2$s angebracht",
    "You unassigned system tag %3$s from %2$s" : "Sie haben den System-Tag %3$s von %2$s  entfernt",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s hat den System-Tag %3$s von %2$s entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");
